@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2026 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,6 +34,9 @@ func existsDo(w io.Writer, fdDepName, cwd, pth string) (bool, error) {
 	if FileExists(path.Join(cwd, pth)) {
 		return true, nil
 	}
+	if w == nil {
+		return false, nil
+	}
 	return false, ifcreate(w, fdDepName, pth)
 }
 
