@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2026 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ import (
 	"io/fs"
 	"log"
 	"os"
+	"path"
 	"strings"
 
 	"golang.org/x/sys/unix"
@@ -74,10 +75,8 @@ func isSrc(tgt *Tgt) bool {
 	if !FileExists(tgt.a) {
 		return false
 	}
-	if FileExists(tgt.a + ".do") {
-		return false
-	}
-	if FileExists(tgt.dep) {
+	tgtH, tgtT := pathSplit(tgt.a)
+	if do, _, _ := findDo(nil, tgt.a, tgtH, tgtT); do != "" {
 		return false
 	}
 	return true
@@ -105,6 +104,9 @@ func isOOD(tgt *Tgt, level int, seen map[string]*Tgt) (bool, error) {
 				if isSrc(tgt) {
 					ood = false
 					tracef(CDebug, "ood: %s%s -> is source", indent, tgt)
+				} else if path.Ext(tgt.a) == ".do" {
+					ood = false
+					tracef(CDebug, "ood: %s%s -> is .do", indent, tgt)
 				} else {
 					ood = true
 					tracef(CDebug, "ood: %s%s -> no dep: %s", indent, tgt, tgt.dep)
