@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2026 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -298,6 +298,19 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		}()
 		return nil
 	}
+	if inodePrev == nil && FileExists(tgt.a) {
+		lockRelease()
+		if StopIfMod {
+			return fmt.Errorf("%s already existing", tgt)
+		}
+		Jobs.Add(1)
+		tracef(CWarn, "%s already existing: not redoing", tgt)
+		go func() {
+			errs <- nil
+			Jobs.Done()
+		}()
+		return nil
+	}
 	dep = nil
 
 	// Start preparing .dep
